@@ -12,7 +12,7 @@ from preseem.model_sync import sync_preseem_model, ElementRole, ElementSyncItem
 from preseem_protobuf.model.element_pb2 import ElementStatus
 from preseem_protobuf.model.account_pb2 import AccountType, AccountStatus
 
-Account = namedtuple('Account', ('id', 'type', 'status', 'company_name', 'first_name', 'last_name'))
+Account = namedtuple('Account', ('id', 'type', 'status', 'name', 'first_name', 'last_name'))
 Package = namedtuple('Package', ('id', 'name', 'download_rate', 'upload_rate'))
 
 #import logging
@@ -622,7 +622,7 @@ class TestModelSync(unittest.TestCase):
             acct = accounts[0]
             self.assertEqual(acct.type, AccountType.ACCOUNT_TYPE_RESIDENTIAL)
             self.assertEqual(acct.status, AccountStatus.ACCOUNT_STATUS_ACTIVE)
-            self.assertEqual(acct.company_name, 'Name01')
+            self.assertEqual(acct.name, 'Name01')
             self.assertEqual(acct.first_name, None)
             self.assertEqual(acct.last_name, None)
         self._await(test())
@@ -685,26 +685,26 @@ class TestModelSync(unittest.TestCase):
                 await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], accounts=accounts)
         self._await(test())
 
-    def test_account_company_name_is_optional(self):
-        """The company_name field is not required."""
+    def test_account_name_is_optional(self):
+        """The name field is not required."""
         async def test():
             accounts = {'acct01': Account('acct01', None, AccountStatus.ACCOUNT_STATUS_ACTIVE, None, None, None)}
             await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], accounts=accounts)
             accounts = await self.model.Account.List(company_uuid=self.company.uuid)
             self.assertEqual(len(accounts), 1)
             acct = accounts[0]
-            self.assertEqual(acct.company_name, None)
+            self.assertEqual(acct.name, None)
 
-    def test_account_company_name_wrong_type_raises_error(self):
-        """The company_name field must be a string type."""
+    def test_account_name_wrong_type_raises_error(self):
+        """The name field must be a string type."""
         async def test():
             accounts = {'acct01': Account('acct01', None, AccountStatus.ACCOUNT_STATUS_ACTIVE, 12334, None, None)}
             with self.assertRaises(ValueError):
                 await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], accounts=accounts)
         self._await(test())
 
-    def test_account_company_name_empty_string_raises_error(self):
-        """The company_name field must not be an empty string."""
+    def test_account_name_empty_string_raises_error(self):
+        """The name field must not be an empty string."""
         async def test():
             accounts = {'acct01': Account('acct01', None, AccountStatus.ACCOUNT_STATUS_ACTIVE, "", None, None)}
             with self.assertRaises(ValueError):
@@ -778,7 +778,7 @@ class TestModelSync(unittest.TestCase):
             acct = accounts[0]
             self.assertEqual(acct.type, AccountType.ACCOUNT_TYPE_RESIDENTIAL)
             self.assertEqual(acct.status, AccountStatus.ACCOUNT_STATUS_ACTIVE)
-            self.assertEqual(acct.company_name, None)
+            self.assertEqual(acct.name, None)
             self.assertEqual(acct.first_name, 'Test')
             self.assertEqual(acct.last_name, 'Account')
             self.assertTrue(acct.updated_at > acct.created_at)
@@ -824,7 +824,7 @@ class TestModelSync(unittest.TestCase):
             self.assertEqual(acct.inactive, False)
             self.assertEqual(acct.type, None)
             self.assertEqual(acct.status, AccountStatus.ACCOUNT_STATUS_ACTIVE)
-            self.assertEqual(acct.company_name, 'Account 1')
+            self.assertEqual(acct.name, 'Account 1')
             self.assertEqual(acct.source, 'test_source')
             self.assertEqual(acct.source_id, 'acct01')
         self._await(test())
